==> owncloud-8.1.0p2.tgz: owncloud/apps/activity/l10n/es.js <==
OC.L10N.register(
    "activity",
    {
    "Activity" : "Actividad",
    "Personal activity feed for %s" : "Alimentador de actividad personal para %s",
    "Your feed URL is invalid" : "Su alimentador URL es inválido",
    "Your settings have been updated." : "Sus ajustes han sido actualizados.",
    "This stream will show events like additions, changes & shares" : "Este fujo mostrará eventos agregados, modificados y compartidos.",
    "There are no events for this filter" : "No hay eventos para este filtro",
    "Activity notification" : "Notificación de actividad",
    "All Activities" : "Todas las actividades",
    "Activities by you" : "Sus actividades",
    "Activities by others" : "Actividades de otros",
    "\"remote user\"" : "\"usuario remoto\"",
    "in %s" : "en %s",
    "%s and %s" : "%s y %s",
    ", " : ", ",
    "_%s and <strong class=\"tooltip\" title=\"%s\">%n more</strong>_::_%s and <strong class=\"tooltip\" title=\"%s\">%n more</strong>_" : ["%s y <strong class=\"tooltip\" title=\"%s\">%n más</strong>","%s y <strong class=\"tooltip\" title=\"%s\">%n más</strong>"],
    "_%s and %n more_::_%s and %n more_" : ["%s y %n más","%s y %n más"],
    "Hello %s," : "Hola %s:",
    "You are receiving this email because in the last hour the following things happened at %s" : "Está recibiendo este mensaje porque durante la última hora han pasado las siguientes cosas en %s",
    "You are receiving this email because in the last day the following things happened at %s" : "Está recibiendo este mensaje porque durante el último día han pasado las siguientes cosas en %s",
    "You are receiving this email because in the last week the following things happened at %s" : "Está recibiendo este mensaje porque durante la última semana han pasado las siguientes cosas en %s ",
    "* %1$s - %2$s" : "* %1$s - %2$s",
    "_* and %n more _::_* and %n more _" : ["* y %n más","* y %n más"],
    "Notifications" : "Notificaciones",
    "Mail" : "Correo electrónico",
    "Stream" : "Flujo",
    "List your own actions in the stream" : "Listar sus propias acciones en el flujo de notificaciones",
    "Notify about your own actions via email" : "Notificarle sus propias acciones por correo electrónico",
    "You need to set up your email address before you can receive notification emails." : "Debe configurar su dirección de correo electrónico antes de poder recibir notificaciones.",
    "Send emails:" : "Enviar mensajes:",
    "Hourly" : "Cada hora",
    "Daily" : "Diariamente",
    "Weekly" : "Semanalmente",
    "Activity feed" : "Alimentador de actividad",
    "Enable RSS feed" : "Habilitar fuente RSS",
    "No activity yet" : "Ninguna actividad aún",
    "No more events to load" : "No hay más eventos por cargar.",
    "Files" : "Archivos"
},
"nplurals=2; plural=(n != 1);");

==> owncloud-9.0.3.tgz: owncloud/apps/activity/l10n/es.js <==
OC.L10N.register(
    "activity",
    {
    "Activity" : "Actividad",
    "Personal activity feed for %s" : "Alimentador de actividad personal para %s",
    "Your feed URL is invalid" : "Su alimentador URL es inválido",
    "Your settings have been updated." : "Sus ajustes han sido actualizados.",
    "Mail" : "Correo electrónico",
    "Stream" : "Flujo",
    "Activities" : "Actividades",
    "Error loading activities" : "Error al cargar actividades",
    "No activities" : "No hay actividades",
    ", " : ", ",
    "{parameterList} and {lastParameter}" : "{parameterList} y {lastParameter}",
    "_{parameterList} and {linkStart}%n more{linkEnd}_::_{parameterList} and {linkStart}%n more{linkEnd}_" : ["{parameterList} y {linkStart}%n más{linkEnd}","{parameterList} y {linkStart}%n más{linkEnd}"],
    "in {directory}" : "en {directory}",
    "This stream will show events like additions, changes & shares" : "Este fujo mostrará eventos agregados, modificados y compartidos.",
    "There are no events for this filter" : "No hay eventos para este filtro",
    "Today" : "Hoy",
    "Yesterday" : "Ayer",
    "\"remote user\"" : "\"usuario remoto\"",
    "Activity notification" : "Notificación de actividad",
    "All Activities" : "Todas las actividades",
    "Activities by you" : "Sus actividades",
    "Activities by others" : "Actividades de otros",
    "%s and %s" : "%s y %s",
    "Hello %s," : "Hola %s:",
    "You are receiving this email because the following things happened at %s" : "Está recibiendo este mensaje porque durante el último día han pasado las siguientes cosas en %s",
    "* %1$s - %2$s" : "* %1$s - %2$s",
    "_* and %n more _::_* and %n more _" : ["* y %n más","* y %n más"],
    "List your own actions in the stream" : "Listar sus propias acciones en el flujo de notificaciones",
    "Notify about your own actions via email" : "Notificarle sus propias acciones por correo electrónico",
    "You need to set up your email address before you can receive notification emails." : "Debe configurar su dirección de correo electrónico antes de poder recibir notificaciones.",
    "Send emails:" : "Enviar mensajes:",
    "Hourly" : "Cada hora",
    "Daily" : "Diariamente",
    "Weekly" : "Semanalmente",
    "Activity feed" : "Alimentador de actividad",
    "Enable RSS feed" : "Habilitar fuente RSS",
    "No activity yet" : "Ninguna actividad aún",
    "No more events to load" : "No hay más eventos por cargar.",
    "Files" : "Archivos"
},
"nplurals=2; plural=(n != 1);");
